CodeQL / Analyze (actions) (push) Canceled after 0s
CodeQL / Analyze (python) (push) Canceled after 0s
pre-commit / pre-commit (push) Canceled after 0s
Multi-Arch CI / setup (push) Canceled after 0s
Publish build_manylinux_x86_64 images / publish_build_manylinux_x86_64 (push) Canceled after 0s
Setup (Multi-Arch) / setup (push) Canceled after 0s
Multi-Arch CI / Linux::${{ fromJSON(needs.setup.outputs.linux_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubi10 image / publish_no_rocm_image_ubi10 (push) Canceled after 0s
Multi-Arch CI / Windows::${{ fromJSON(needs.setup.outputs.windows_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Multi-Arch CI / Manifest Diff (push) Canceled after 0s
TheRock Manifest Diff Report / Generate Manifest Diff Report (push) Canceled after 0s
Multi-Arch CI / CI Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_ocl_rt images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_rocgdb images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Unit Tests / Unit Tests :: ubuntu-24.04 (push) Canceled after 0s
Unit Tests / Unit Tests :: windows-2022 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_media (push) Canceled after 0s
Unit Tests / Unit Tests Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_openmpi (push) Canceled after 0s
46 lines
1.5 KiB
Plaintext
46 lines
1.5 KiB
Plaintext
// Minimal HIP vector-add kernel — fixture used by ml_scenarios.rs
|
|
// (only compiled when a HIP toolchain is present on the host).
|
|
//
|
|
// hipcc tests/fixtures/ml/tiny_hip.hip -o tiny_hip && ./tiny_hip
|
|
//
|
|
// Prints `hip_kernel_ok` on success.
|
|
|
|
#include <hip/hip_runtime.h>
|
|
#include <stdio.h>
|
|
#include <stdlib.h>
|
|
#include <unistd.h>
|
|
|
|
__global__ void add(const float* a, const float* b, float* c, int n) {
|
|
int i = blockIdx.x * blockDim.x + threadIdx.x;
|
|
if (i < n) c[i] = a[i] + b[i];
|
|
}
|
|
|
|
int main() {
|
|
const int n = 16;
|
|
float h_a[n], h_b[n], h_c[n];
|
|
for (int i = 0; i < n; ++i) { h_a[i] = (float)i; h_b[i] = 2.0f * i; }
|
|
float *d_a, *d_b, *d_c;
|
|
hipMalloc(&d_a, n * sizeof(float));
|
|
hipMalloc(&d_b, n * sizeof(float));
|
|
hipMalloc(&d_c, n * sizeof(float));
|
|
hipMemcpy(d_a, h_a, n * sizeof(float), hipMemcpyHostToDevice);
|
|
hipMemcpy(d_b, h_b, n * sizeof(float), hipMemcpyHostToDevice);
|
|
hipLaunchKernelGGL(add, dim3(1), dim3(n), 0, 0, d_a, d_b, d_c, n);
|
|
hipDeviceSynchronize();
|
|
hipMemcpy(h_c, d_c, n * sizeof(float), hipMemcpyDeviceToHost);
|
|
int errors = 0;
|
|
for (int i = 0; i < n; ++i) {
|
|
if (h_c[i] != 3.0f * i) { fprintf(stderr, "mismatch at %d: %f vs %f\n", i, h_c[i], 3.0f * i); ++errors; }
|
|
}
|
|
hipFree(d_a); hipFree(d_b); hipFree(d_c);
|
|
hipDeviceReset();
|
|
if (errors) {
|
|
// _exit avoids HIP/HSA atexit handlers that hang under the simulator
|
|
// (see rocjitsu tests/hip_vector_add_test.cpp main()).
|
|
_exit(1);
|
|
}
|
|
printf("hip_kernel_ok\n");
|
|
fflush(stdout);
|
|
_exit(0);
|
|
}
|